==> gridx-1.3-javadoc.jar: nls/bg/gridx.js <==
define({     
//Body
	loadingInfo: "Зареждане...",
	emptyInfo: "Няма елементи за изобразяване",
	loadFailInfo: "Неуспешно зареждане на данни!",
	loadMore: "Зареждане на повече",
	loadMoreLoading: "Зареждане...",
	loadPrevious: "Зареждане на предишен",
	loadPreviousLoading: "Зареждане...",

//FilterBar
	"clearFilterDialogTitle": "Изчистване на филтър",
	"filterDefDialogTitle": "Филтър",
	"defaultRuleTitle": "Правило",
	"ruleTitleTemplate": "Правило ${ruleNumber}",
	"noFilterApplied": "Не е приложен филтър.",
	"defineFilter": "Определяне на филтър",
	"conditionEqual": "равен",
	"conditionNotEqual": "не е равен",
	"conditionLess": "е по-малък от",
	"conditionLessEqual": "по-малък или равен",
	"conditionGreater": "е по-голям от",
	"conditionGreaterEqual": "по-голям от или равен",
	"conditionContain": "съдържа",
	"conditionIs": "е",
	"conditionStartWith": "започва с",
	"conditionEndWith": "завършва с",
	"conditionNotContain": "не съдържа",
	"conditionIsNot": "не е",
	"conditionNotStartWith": "не започва с",
	"conditionNotEndWith": "не завършва с",
	"conditionBefore": "преди",
	"conditionAfter": "след",
	"conditionRange": "обхват",
	"conditionIsEmpty": "е празен",
	"all": "всички",
	"any": "някои",
	"relationAll": "всички правила",
	"waiRelAll": "Съвпадане на всички от следните правила:",
	"relationAny": "някое правило",
	"waiRelAny": "Съвпадане на някое от следните правила:",
	"relationMsgFront": "Съвпадение",
	"relationMsgTail": "",
	"and": "и",
	"or": "или",
	"addRuleButton": "Добавяне на правило",
	"waiAddRuleButton": "Добавяне на ново правило",
	"removeRuleButton": "Премахване на правило",
	"waiRemoveRuleButtonTemplate": "Премахване на правило ${0}",
	"addRuleButton": "Добавяне на правило за филтър",
	"cancelButton": "Отказ",
	"waiCancelButton": "Отказване на този диалог",
	"clearButton": "Изчистване",
	"waiClearButton": "Изчистване на филтър",
	"filterButton": "Филтър",
	"waiFilterButton": "Подаване на филтъра",
	"columnSelectLabel": "Колона:",
	"waiColumnSelectTemplate": "Колона за правило ${0}",
	"conditionSelectLabel": "Условие:",
	"waiConditionSelectTemplate": "Условие за правило ${0}",
	"valueBoxLabel": "Стойност:",
	"waiValueBoxTemplate": "Въведете стойност за филтър за правило ${0}",
	"rangeTo": "до",
	"rangeTemplate": "от ${0} до ${1}",
	"statusTipHeaderColumn": "Колона",
	"statusTipHeaderCondition": "Правила",
	"statusTipTitle": "Лента с филтри",
	"statusTipMsg": "Щракнете върху лентата с филтри тук, за да филтрирате по стойности в ${0}.",
	"anycolumn": "някоя колона",
	"statusTipTitleNoFilter": "Лента с филтри",
	"statusTipTitleHasFilter": "Филтър",
	"statusTipRelPre": "Съвпадение",
	"statusTipRelPost": "правила.",
	"statusTipHeaderAll": "Съвпадение на всички правила.",
	"statusTipHeaderAny": "Съвпадение на някои правила.",
	"defaultItemsName": "елементи",
	"filterBarMsgHasFilterTemplate": "Показани са ${0} от ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Не е приложен филтър",
	"filterBarDefButton": "Определяне на филтър",
	"waiFilterBarDefButton": "Филтриране на таблицата",
	"a11yFilterBarDefButton": "Филтър...",
	"filterBarClearButton": "Изчистване на филтър",
	"waiFilterBarClearButton": "Изчистване на филтър",
	"closeFilterBarBtn": "Затваряне на лентата с филтри",
	"clearFilterMsg": "Това ще премахне филтъра и ще покаже всички налични записи.",
	"anyColumnOption": "Някоя колона",
	"trueLabel": "Вярно",
	"falseLabel": "Грешно",
	"radioTrueLabel": "Вярна стойност",
	"radioFalseLabel": "Грешна стойност",
	"beginTimeRangeLabel": "Начална стойност за времеви обхват",
	"endTimeRangeLabel": "Крайна стойност за времеви обхват",
	"beginDateRangeLabel": "Начална стойност на обхват от данни",
	"endDateRangeLabel": "Крайна стойност на обхват от данни",
	"startsWithExpr": "${0}*",

//NestedSort
	singleSort: "Единично сортиране",
	nestedSort: "Вложено сортиране",
	ascending: "Щракнете, за да сортирате възходящо",
	descending: "Щракнете, за да сортирате низходящо",
	sortingState: "${0} - ${1}",
	unsorted: "Не сортирайте тази колона",
	waiSingleSortLabel: "${0} - е сортиран по ${1}. Изберете да сортирате по ${2}",
	waiNestedSortLabel:"${0} - е вложен по ${1}. Изберете за вложено сортиране по ${2}",

//PaginationBar
	pagerWai: 'Страньор',

	pageIndex: '${0}',
	pageIndexTitle: 'Страница ${0}',

	firstPageTitle: 'Първа страница',
	prevPageTitle: 'Предишна страница',
	nextPageTitle: 'Следваща страница',
	lastPageTitle: 'Последна страница',

	pageSize: '${0}',
	pageSizeTitle: '${0} елемента на страница',
	pageSizeAll: 'Всички',
	pageSizeAllTitle: 'Всички елементи',

	description: '${0} - ${1} от ${2} елемента.',
	descriptionEmpty: 'Мрежата е празна.',

	summary: 'Общо: ${0}',
	summaryWithSelection: 'Общо: ${0} Избрани: ${1}',

	gotoBtnTitle: 'Отиване на конкретна страница',

	gotoDialogTitle: 'Отиди на страница',
	gotoDialogMainMsg: 'Указване на номер на страница:',
	gotoDialogPageCount: '(${0} страници)',
	gotoDialogOKBtn: 'Отиди',
	gotoDialogCancelBtn: 'Отказ',
	// for drop down pagination bar
	pageLabel: 'Страница',
	pageSizeLabel: 'Редове',

//QuickFilter
	filterLabel: 'Филтър',
	clearButtonTitle: 'Изчистване на филтър',
	buildFilterMenuLabel: 'Вграждане на филтър&hellip;',
	apply: 'Прилагане на филтър',

//Sort
	helpMsg: '${0} - Щракнете, за да сортирате или щракнете върху control, за да добавите сортиране',
	singleHelpMsg: '${0} - Щракнете, за да сортирате',
	priorityOrder: 'Приоритет на сортиране ${0}',

//SummaryBar
	summaryTotal: 'Общо: ${0}',
	summarySelected: 'Избрани: ${0}',
	summaryRange: 'Обхват: ${0}-${1}',	//need translation

//Other
	indirectSelectAll: "Натиснете SPACE, за да изберете всички.",	//need translation
	indirectDeselectAll: "Натиснете SPACE, за да откажете всички.",	//need translation
	treeExpanded: "Control + лява стрелка, за да сгънете този ред.",	//need translation
	treeCollapsed: "Control + дясна стрелка, за да разширите този ред."	//need translation
});

==> gridx-1.3.8-javadoc.jar: nls/bg/gridx.js <==
define({     
//Body
	loadingInfo: "Зареждане...",
	emptyInfo: "Няма елементи за изобразяване",
	loadFailInfo: "Неуспешно зареждане на данни!",
	loadMore: "Зареждане на повече",
	loadMoreLoading: "Зареждане...",
	loadPrevious: "Зареждане на предишен",
	loadPreviousLoading: "Зареждане...",

//FilterBar
	"clearFilterDialogTitle": "Изчистване на филтър",
	"filterDefDialogTitle": "Филтър",
	"defaultRuleTitle": "Правило",
	"ruleTitleTemplate": "Правило ${ruleNumber}",
	"noFilterApplied": "Не е приложен филтър.",
	"defineFilter": "Определяне на филтър",
	"defineFilterAriaLabel": "Определяне на филтър: Отваря диалогов прозорец за филтри, който служи за конфигуриране на комплексни правила за филтри. Всяко правило за филтър се състои от комбинация от колона, условие и стойност. При отварянето на диалоговия прозорец фокусът на клавиатурата ще бъде върху полето за стойност.",
	"conditionEqual": "равен",
	"conditionNotEqual": "не е равен",
	"conditionLess": "е по-малък от",
	"conditionLessEqual": "по-малък или равен",
	"conditionGreater": "е по-голям от",
	"conditionGreaterEqual": "по-голям от или равен",
	"conditionContain": "съдържа",
	"conditionIs": "е",
	"conditionStartWith": "започва с",
	"conditionEndWith": "завършва с",
	"conditionNotContain": "не съдържа",
	"conditionIsNot": "не е",
	"conditionNotStartWith": "не започва с",
	"conditionNotEndWith": "не завършва с",
	"conditionBefore": "преди",
	"conditionAfter": "след",
	"conditionRange": "обхват",
	"conditionIsEmpty": "е празен",
	"conditionIsNotEmpty": "не е празен",
	"all": "всички",
	"any": "някои",
	"relationAll": "всички правила",
	"waiRelAll": "Съвпадане на всички от следните правила:",
	"relationAny": "някое правило",
	"waiRelAny": "Съвпадане на някое от следните правила:",
	"relationMsgFront": "Съвпадение",
	"relationMsgTail": "",
	"and": "и",
	"or": "или",
	"addRuleButton": "Добавяне на правило",
	"waiAddRuleButton": "Добавяне на ново правило",
	"removeRuleButton": "Премахване на правило",
	"waiRemoveRuleButtonTemplate": "Премахване на правило ${0}",
	"addRuleButton": "Добавяне на правило за филтър",
	"cancelButton": "Отказ",
	"waiCancelButton": "Отказване на този диалог",
	"clearButton": "Изчистване",
	"waiClearButton": "Изчистване на филтъра",
	"filterButton": "Филтър",
	"waiFilterButton": "Подаване на филтъра",
	"columnSelectLabel": "Колона:",
	"columnSelectAriaLabel": "Колона: условие част ${0} от ${1}",
	"waiColumnSelectTemplate": "Колона за правило ${0}",

	"conditionSelectLabel": "Условие:",
	"conditionSelectAriaLabel": "Оператор: условие част ${0} от ${1}",
	"waiConditionSelectTemplate": "Условие за правило ${0}",

	"valueBoxLabel": "Стойност:",
	"valueBoxAriaLabel": "Стойност: условие част ${0} от ${1}",
	"waiValueBoxTemplate": "Въведете стойност за филтър за правило ${0}",
	"rangeTo": "до",
	"rangeTemplate": "от ${0} до ${1}",
	"statusTipHeaderColumn": "Колона",
	"statusTipHeaderCondition": "Правила",
	"statusTipTitle": "Лента с филтри",
	"statusTipMsg": "Щракнете върху лентата с филтри тук, за да филтрирате по стойности в ${0}.",
	"anycolumn": "някоя колона",
	"statusTipTitleNoFilter": "Лента с филтри",
	"statusTipTitleHasFilter": "Филтър",
	"statusTipRelPre": "Съвпадение",
	"statusTipRelPost": "правила.",
	"statusTipHeaderAll": "Съвпадение на всички правила.",
	"statusTipHeaderAny": "Съвпадение на някои правила.",
	"defaultItemsName": "елементи",
	"filterBarMsgHasFilterTemplate": "Показани са ${0} от ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Не е приложен филтър",
	"filterBarDefButton": "Определяне на филтър",
	"waiFilterBarDefButton": "Филтриране на таблицата",
	"a11yFilterBarDefButton": "Филтриране...",
	"filterBarClearButton": "Изчистване на филтър",
	"waiFilterBarClearButton": "Изчистване на филтъра",
	"closeFilterBarBtn": "Затваряне на лентата с филтри",
	"clearFilterMsg": "Това ще премахне филтъра и ще покаже всички налични записи.",
	"anyColumnOption": "Някоя колона",
	"trueLabel": "Вярно",
	"falseLabel": "Грешно",
	"radioTrueLabel": "Вярна стойност",
	"radioFalseLabel": "Грешна стойност",
	"beginTimeRangeLabel": "Начална стойност за времеви обхват",
	"endTimeRangeLabel": "Крайна стойност за времеви обхват",
	"beginDateRangeLabel": "Начална стойност на обхват от данни",
	"endDateRangeLabel": "Крайна стойност на обхват от данни",
	"startsWithExpr": "${0}*",

//NestedSort
	singleSort: "Единично сортиране",
	nestedSort: "Вложено сортиране",
	ascending: "Щракнете, за да сортирате възходящо",
	descending: "Щракнете, за да сортирате низходящо",
	sortingState: "${0} - ${1}",
	unsorted: "Не сортирайте тази колона",
	waiSingleSortLabel: "${0} - е сортиран по ${1}. Изберете да сортирате по ${2}",
	waiNestedSortLabel:"${0} - е вложен по ${1}. Изберете за вложено сортиране по ${2}",

//PaginationBar
	pagerWai: 'Страньор',

	pageIndex: '${0}',
	pageIndexTitle: 'Страница ${0}',

	firstPageTitle: 'Първа страница',
	prevPageTitle: 'Предишна страница',
	nextPageTitle: 'Следваща страница',
	lastPageTitle: 'Последна страница',

	pageSize: '${0}',
	pageSizeTitle: '${0} елемента на страница',
	pageSizeAll: 'Всички',
	pageSizeAllTitle: 'Всички елементи',

	description: '${0} - ${1} от ${2} елемента.',
	descriptionEmpty: 'Мрежата е празна.',

	summary: 'Общо: ${0}',
	summaryWithSelection: 'Общо: ${0} Избрани: ${1}',

	gotoBtnTitle: 'Отиване на конкретна страница',

	gotoDialogTitle: 'Отиди на страница',
	gotoDialogMainMsg: 'Указване на номер на страница:',
	gotoDialogPageCount: '(${0} страници)',
	gotoDialogOKBtn: 'Отиди',
	gotoDialogCancelBtn: 'Отказ',
	// for drop down pagination bar
	pageLabel: 'Страница',
	pageSizeLabel: 'Редове',

//QuickFilter
	filterLabel: 'Филтър',
	clearButtonTitle: 'Изчистване на филтър',
	buildFilterMenuLabel: 'Вграждане на филтър…',
	apply: 'Прилагане на филтър',

//Sort
	helpMsg: '${0} - Щракнете, за да сортирате, или щракнете с натиснат control, за да добавите сортиране',
	singleHelpMsg: '${0} - Щракнете, за да сортирате',
	priorityOrder: 'Приоритет на сортиране ${0}',

//SummaryBar
	summaryTotal: 'Общо: ${0}',
	summarySelected: 'Избрани: ${0}',
	summaryRange: 'Обхват: ${0}-${1}',	//need translation

//Other
	indirectSelectAll: "Натиснете SPACE, за да изберете всички.",	//need translation
	indirectDeselectAll: "Натиснете SPACE, за да откажете всички.",	//need translation
	treeExpanded: "Control + лява стрелка, за да сгънете този ред.",	//need translation
	treeCollapsed: "Control + дясна стрелка, за да разширите този ред."	//need translation
});
